from dataclasses import dataclass
from typing import Dict, List, Optional

import grpc
from _qwak_proto.qwak.build.v1.build_api_pb2 import (
    GetBuildRequest,
    GetBuildResponse,
    ListBuildsRequest,
    ListBuildsResponse,
    LogPhaseStatusRequest,
    PhaseStatus,
    RegisterExperimentTrackingRequest,
    RegisterExperimentTrackingResponse,
    RegisterModelSchemaRequest,
    RegisterModelSchemaResponse,
    RegisterTagsRequest,
    RegisterTagsResponse,
    UpdateBuildStatusRequest,
    UpdateBuildStatusResponse,
    SaveFrameworkModelsRequest,
    SaveFrameworkModelsResponse,
)
from _qwak_proto.qwak.build.v1.build_api_pb2_grpc import BuildAPIStub
from _qwak_proto.qwak.build.v1.build_pb2 import (
    BuildFilter,
    BuildStatus,
    ModelSchema,
    FrameworkModelsSpec,
    HuggingFaceModelSpec,
    FrameworkModel,
)
from _qwak_proto.qwak.build_settings.build_settings_api_pb2 import (
    GetBuildSettingsResponse,
    GetBuildSettingsRequest,
)
from _qwak_proto.qwak.build_settings.build_settings_api_pb2_grpc import (
    BuildSettingsApiStub,
)
from _qwak_proto.qwak.builds.build_pb2 import BaseDockerImageType, DataTableDefinition
from _qwak_proto.qwak.builds.build_url_pb2 import (
    BuildVersioningUrlParams,
    BuildVersioningTagsType,
)
from _qwak_proto.qwak.builds.builds_orchestrator_service_pb2 import (
    BuildModelRequest,
    CancelBuildModelRequest,
    CreateDataTableRequest,
    CreateDataTableResponse,
    GetBaseDockerImageNameRequest,
    GetBaseDockerImageNameResponse,
    GetBuildVersioningDownloadURLRequest,
    GetBuildVersioningDownloadURLResponse,
    GetBuildVersioningUploadURLRequest,
    GetBuildVersioningUploadURLResponse,
)
from _qwak_proto.qwak.builds.builds_orchestrator_service_pb2_grpc import (
    BuildsOrchestratorServiceStub,
)
from dependency_injector.wiring import Provide
from qwak.clients.build_orchestrator.build_model_request_getter import (
    _get_build_model_spec,
)
from qwak.exceptions import QwakException
from qwak.inner.di_configuration import QwakContainer
from qwak.inner.tool.grpc.grpc_try_wrapping import grpc_try_catch_wrapper


@dataclass
class FrameworkModelDataClass:
    pass


@dataclass
class HuggingModelDataClass(FrameworkModelDataClass):
    models_name_to_versions: Dict[str, List[str]]
    repository: Optional[str] = None


@dataclass
class HuggingFaceModel(FrameworkModelDataClass):
    model_name: str
    version: str
    repository: str
    sha1: str


class BuildOrchestratorClient:
    def __init__(self, grpc_channel=Provide[QwakContainer.core_grpc_channel]):
        self._builds_orchestrator_stub_build_api = BuildAPIStub(grpc_channel)
        self._builds_orchestrator_stub = BuildsOrchestratorServiceStub(grpc_channel)
        self._build_settings_stub = BuildSettingsApiStub(grpc_channel)

    @grpc_try_catch_wrapper("Failed to update build status")
    def update_build_status(
        self, build_id: str, build_status: BuildStatus
    ) -> UpdateBuildStatusResponse:
        request = UpdateBuildStatusRequest(buildId=build_id, build_status=build_status)
        return self._builds_orchestrator_stub_build_api.UpdateBuildStatus(request)

    @grpc_try_catch_wrapper("Failed to register model schema")
    def register_model_schema(
        self, build_id: str, model_schema: ModelSchema
    ) -> RegisterModelSchemaResponse:
        request = RegisterModelSchemaRequest(
            build_id=build_id, model_schema=model_schema
        )
        return self._builds_orchestrator_stub_build_api.RegisterModelSchema(request)

    @grpc_try_catch_wrapper("Failed to register experiment tracking values")
    def register_experiment_tracking(
        self,
        build_id: str,
        params: Dict[str, str] = None,
        metrics: Dict[str, float] = None,
    ) -> RegisterExperimentTrackingResponse:
        params = params if params else {}
        metrics = metrics if metrics else {}

        transformed_params = {k: str(v) for k, v in params.items()}
        transformed_metrics = {k: float(v) for k, v in metrics.items()}

        request = RegisterExperimentTrackingRequest(
            build_id=build_id, params=transformed_params, metrics=transformed_metrics
        )
        return self._builds_orchestrator_stub_build_api.RegisterExperimentTracking(
            request
        )

    @grpc_try_catch_wrapper("Failed to save framework models")
    def save_framework_models(
        self, build_id: str, frameworks_model_data_class: List[FrameworkModelDataClass]
    ) -> SaveFrameworkModelsResponse:
        framework_models = []
        for framework_model_data_class in frameworks_model_data_class:
            if isinstance(framework_model_data_class, HuggingModelDataClass):
                for (
                    huggingface_model_name,
                    versions,
                ) in framework_model_data_class.models_name_to_versions.items():
                    for version in versions:
                        framework_models.append(
                            FrameworkModel(
                                huggingface_model_spec=HuggingFaceModelSpec(
                                    version=version,
                                    model_name=huggingface_model_name,
                                    repository=framework_model_data_class.repository,
                                )
                            )
                        )

        request = SaveFrameworkModelsRequest(
            spec=FrameworkModelsSpec(
                build_id=build_id, framework_models=framework_models
            )
        )

        return self._builds_orchestrator_stub_build_api.SaveFrameworkModels(request)

    @grpc_try_catch_wrapper("Failed to save framework models")
    def save_used_framework_models(
        self, build_id: str, models: List[HuggingFaceModel]
    ) -> SaveFrameworkModelsResponse:
        framework_models = []
        for model in models:
            if isinstance(model, HuggingFaceModel):
                framework_models.append(
                    FrameworkModel(
                        huggingface_model_spec=HuggingFaceModelSpec(
                            version=model.version,
                            model_name=model.model_name,
                            sha1=model.sha1,
                            repository=model.repository,
                        )
                    )
                )
        request = SaveFrameworkModelsRequest(
            spec=FrameworkModelsSpec(
                build_id=build_id, framework_models=framework_models
            )
        )

        return self._builds_orchestrator_stub_build_api.SaveFrameworkModels(request)

    @grpc_try_catch_wrapper("Failed to register tags")
    def register_tags(
        self,
        build_id: str,
        tags: List[str],
    ) -> RegisterTagsResponse:
        request = RegisterTagsRequest(build_id=build_id, tags=tags)
        return self._builds_orchestrator_stub_build_api.RegisterTags(request)

    @grpc_try_catch_wrapper("Failed to list builds")
    def list_builds(
        self, model_uuid: str = "", build_filter: BuildFilter = None, **kwargs
    ) -> ListBuildsResponse:
        _model_uuid = model_uuid if model_uuid else kwargs.get("branch_id")
        if not _model_uuid:
            raise QwakException("missing argument model uuid or branch id.")

        request = ListBuildsRequest(model_uuid=_model_uuid, filter=build_filter)
        return self._builds_orchestrator_stub_build_api.ListBuilds(request)

    @grpc_try_catch_wrapper("Failed to get build")
    def get_build(self, build_id: str) -> GetBuildResponse:
        request = GetBuildRequest(build_id=build_id)
        return self._builds_orchestrator_stub_build_api.GetBuild(request)

    def is_build_exists(self, build_id: str) -> bool:
        try:
            build: GetBuildResponse = self.get_build(build_id)
            if build.build.build_spec.build_id == build_id:
                return True
            return False
        except grpc.RpcError as e:
            if e.code() == grpc.StatusCode.NOT_FOUND:
                return False
            raise QwakException(
                f"Failed to check if build {build_id} is exists, error is {e.details()}"
            )

    @grpc_try_catch_wrapper("Failed to get build versioning upload url")
    def get_build_versioning_upload_url(
        self,
        build_id: str,
        model_id: str,
        tag: str,
        tag_type: BuildVersioningTagsType = BuildVersioningTagsType.INVALID_TAG_TYPE,
    ) -> GetBuildVersioningUploadURLResponse:
        """Get Upload pre signed url

        Args:
            model_id: Model ID
            build_id: Build ID
            tag: the tag to save the artifact by
            tag_type: the type of the file to upload

        Returns:
            the upload url
        """
        return self._builds_orchestrator_stub.GetBuildVersioningUploadURL(
            GetBuildVersioningUploadURLRequest(
                params=BuildVersioningUrlParams(
                    build_id=build_id,
                    model_id=model_id,
                    tag=tag,
                    tag_type=tag_type,
                )
            )
        )

    def get_build_versioning_download_url(
        self,
        build_id: str,
        model_id: str,
        tag: str,
        tag_type: BuildVersioningTagsType = BuildVersioningTagsType.INVALID_TAG_TYPE,
    ) -> GetBuildVersioningDownloadURLResponse:
        """Get Download url

        Args:
            model_id: Model ID
            build_id: Build ID
            tag: the tag to save the artifact by
            tag_type: the type of the file to download

        Returns:
            the pre signed download url
        """
        try:
            return self._builds_orchestrator_stub.GetBuildVersioningDownloadURL(
                GetBuildVersioningDownloadURLRequest(
                    params=BuildVersioningUrlParams(
                        build_id=build_id, model_id=model_id, tag=tag, tag_type=tag_type
                    )
                )
            )
        except grpc.RpcError as e:
            if e.code() == grpc.StatusCode.NOT_FOUND:
                print(
                    "The specified file cannot be found. Please verify the file name before trying again"
                )
                raise QwakException(
                    "The specified file cannot be found. Please verify the file name before trying again"
                )
            else:
                print(f"Failed to get build versioning download url. Error is {e}")
                raise QwakException(
                    f"The specified file cannot be loaded. Error is {e}"
                )

        except Exception as e:
            print(f"Failed to get build versioning download url. Error is {e}")
            raise QwakException(
                f"Failed to get build versioning download url. Error is {e}"
            )

    @grpc_try_catch_wrapper("Failed to get build settings")
    def get_build_settings(self, environment_id: str) -> GetBuildSettingsResponse:
        """Get BuildSettings

        Args:
            environment_id: Environment ID

        Returns:
            the build settings by the environment ID
        """
        return self._build_settings_stub.GetBuildSettings(
            GetBuildSettingsRequest(
                environment_id=environment_id,
            )
        )

    @grpc_try_catch_wrapper("Failed to define a table for the data")
    def define_build_data_table(
        self, build_id: str, model_id: str, tag: str, table: DataTableDefinition
    ) -> CreateDataTableResponse:
        """Define Build Data Table

        Args:
            model_id: Model ID
            build_id: Build ID
            tag: tag for the data
            table: the data to save the table for

        Returns:
            the pre signed download url
        """
        return self._builds_orchestrator_stub.CreateDataTable(
            CreateDataTableRequest(
                build_id=build_id,
                model_id=model_id,
                tag=tag,
                table=table,
            )
        )

    @grpc_try_catch_wrapper("Failed to log build phase status")
    def log_phase_status(
        self,
        build_id: str,
        phase_id: str,
        phase_status: PhaseStatus,
        duration_in_seconds: int,
    ) -> None:
        if build_id:
            request = LogPhaseStatusRequest(
                build_id=build_id,
                phase_id=phase_id,
                status=phase_status,
                phase_duration_in_seconds=duration_in_seconds,
            )
            self._builds_orchestrator_stub_build_api.LogPhaseStatus(request)

        else:
            print(f"No build id. Cannot log phase status: {phase_id} {phase_status}")

    def build_model(
        self,
        build_conf,
        verbose: int = 3,
        git_commit_id: str = "",
        resolved_model_url: str = "",
        build_code_path: str = "",
        build_v1_flag: bool = False,
        build_config_url: str = "",
        qwak_sdk_wheel_url: str = "",
        qwak_sdk_version_url: str = "",
        build_steps: Optional[List[str]] = None,
        sdk_version: str = "",
    ):
        """Initiate remote build

        Args:
            verbose: log verbosity level
            git_commit_id: commit id
            resolved_model_url: the url of model
            build_conf: the build configuration
            build_code_path: The code  path saved by qwak
            build_v1_flag:
            build_config_url:
            qwak_sdk_wheel_url:
            qwak_sdk_version_url:
            build_steps: List of the steps the build is comprised from
            sdk_version: The sdk version to build the

        Raises:
            QwakException: In case of failing to connect the service
        """
        build_steps = build_steps if build_steps else []

        try:
            build_spec = _get_build_model_spec(
                build_conf,
                verbose,
                git_commit_id,
                resolved_model_url,
                build_code_path,
                build_v1_flag,
                build_config_url,
                qwak_sdk_wheel_url,
                qwak_sdk_version_url,
                build_steps,
                sdk_version,
            )
            self._builds_orchestrator_stub.BuildModel(
                BuildModelRequest(build_spec=build_spec)
            )
        except grpc.RpcError as e:
            message = (
                f"Failed to build model, status [{e.code()}] details [{e.details()}]"
            )
            raise QwakException(message)

        except Exception as e:
            message = f"Failed to build model, details [{e}]"
            raise QwakException(message)

    def cancel_build_model(self, build_id: str):
        """cancel remote build process

        Args:
            build_id: The build ID to cancel

        Raises:
            QwakException: In case of failing to connect the service
        """
        try:
            self._builds_orchestrator_stub.CancelBuildModel(
                CancelBuildModelRequest(build_id=build_id)
            )
        except grpc.RpcError as e:
            raise QwakException(
                f"Failed to cancel build, status [{e.code()}] details [{e.details()}]"
            )

    def fetch_base_docker_image_name(
        self, type: BaseDockerImageType
    ) -> GetBaseDockerImageNameResponse:
        """Retrieve the base docker image name for a given build type
        Args:
            type: The build type (CPU or GPU)
        Returns:
            The base docker image name
        Raises:
            QwakException: In case of failing to connect the service
        """
        try:
            return self._builds_orchestrator_stub.GetBaseDockerImageName(
                GetBaseDockerImageNameRequest(base_docker_image_type=type)
            )
        except grpc.RpcError as e:
            raise QwakException(
                f"Failed to retrieve base docker image name, status [{e.code()}] details [{e.details()}]"
            )



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import qwak.feature_store.sources.batch_pb2
import qwak.feature_store.sources.data_source_attribute_pb2
import qwak.feature_store.sources.streaming_pb2
import qwak.feature_store.v1.common.source_code.source_code_pb2
import sys
import typing

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class DataSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATA_SOURCE_DEFINITION_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    FEATURE_SETS_FIELD_NUMBER: builtins.int
    @property
    def data_source_definition(self) -> global___DataSourceDefinition:
        """Complete domain definition of the data source"""
    @property
    def metadata(self) -> global___DataSourceMetadata:
        """System generated metadata of the data source"""
    @property
    def feature_sets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___FeatureSetBrief]:
        """Linked feature sets"""
    def __init__(
        self,
        *,
        data_source_definition: global___DataSourceDefinition | None = ...,
        metadata: global___DataSourceMetadata | None = ...,
        feature_sets: collections.abc.Iterable[global___FeatureSetBrief] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["data_source_definition", b"data_source_definition", "metadata", b"metadata"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["data_source_definition", b"data_source_definition", "feature_sets", b"feature_sets", "metadata", b"metadata"]) -> None: ...

global___DataSource = DataSource

class DataSourceDefinition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATA_SOURCE_ID_FIELD_NUMBER: builtins.int
    DATA_SOURCE_SPEC_FIELD_NUMBER: builtins.int
    data_source_id: builtins.str
    """Assigned unique id"""
    @property
    def data_source_spec(self) -> global___DataSourceSpec:
        """Specifications of the data source"""
    def __init__(
        self,
        *,
        data_source_id: builtins.str = ...,
        data_source_spec: global___DataSourceSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["data_source_spec", b"data_source_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["data_source_id", b"data_source_id", "data_source_spec", b"data_source_spec"]) -> None: ...

global___DataSourceDefinition = DataSourceDefinition

class DataSourceMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATED_AT_FIELD_NUMBER: builtins.int
    CREATED_BY_FIELD_NUMBER: builtins.int
    LAST_MODIFIED_AT_FIELD_NUMBER: builtins.int
    LAST_MODIFIED_BY_FIELD_NUMBER: builtins.int
    ENVIRONMENT_ID_FIELD_NUMBER: builtins.int
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """When the data source was created"""
    created_by: builtins.str
    """Created by"""
    @property
    def last_modified_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Last modified"""
    last_modified_by: builtins.str
    """Last modified by"""
    environment_id: builtins.str
    """Environment id"""
    def __init__(
        self,
        *,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        created_by: builtins.str = ...,
        last_modified_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        last_modified_by: builtins.str = ...,
        environment_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["created_at", b"created_at", "last_modified_at", b"last_modified_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["created_at", b"created_at", "created_by", b"created_by", "environment_id", b"environment_id", "last_modified_at", b"last_modified_at", "last_modified_by", b"last_modified_by"]) -> None: ...

global___DataSourceMetadata = DataSourceMetadata

class DataSourceSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BATCH_SOURCE_FIELD_NUMBER: builtins.int
    STREAM_SOURCE_FIELD_NUMBER: builtins.int
    SOURCE_CODE_SPEC_FIELD_NUMBER: builtins.int
    DATA_SOURCE_ATTRIBUTES_FIELD_NUMBER: builtins.int
    FEATURESET_REPOSITORY_NAME_FIELD_NUMBER: builtins.int
    DATA_SOURCE_REPOSITORY_NAME_FIELD_NUMBER: builtins.int
    @property
    def batch_source(self) -> qwak.feature_store.sources.batch_pb2.BatchSource: ...
    @property
    def stream_source(self) -> qwak.feature_store.sources.streaming_pb2.StreamingSource: ...
    @property
    def source_code_spec(self) -> qwak.feature_store.v1.common.source_code.source_code_pb2.SourceCodeSpec: ...
    @property
    def data_source_attributes(self) -> qwak.feature_store.sources.data_source_attribute_pb2.DataSourceAttributes:
        """Data source attributes"""
    featureset_repository_name: builtins.str
    """This field is marked as deprecated
    Typo in the name
    """
    data_source_repository_name: builtins.str
    """Data source repository name"""
    def __init__(
        self,
        *,
        batch_source: qwak.feature_store.sources.batch_pb2.BatchSource | None = ...,
        stream_source: qwak.feature_store.sources.streaming_pb2.StreamingSource | None = ...,
        source_code_spec: qwak.feature_store.v1.common.source_code.source_code_pb2.SourceCodeSpec | None = ...,
        data_source_attributes: qwak.feature_store.sources.data_source_attribute_pb2.DataSourceAttributes | None = ...,
        featureset_repository_name: builtins.str = ...,
        data_source_repository_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["batch_source", b"batch_source", "data_source_attributes", b"data_source_attributes", "data_source_repository_identifier", b"data_source_repository_identifier", "data_source_repository_name", b"data_source_repository_name", "featureset_repository_identifier", b"featureset_repository_identifier", "featureset_repository_name", b"featureset_repository_name", "source_code_spec", b"source_code_spec", "stream_source", b"stream_source", "type", b"type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["batch_source", b"batch_source", "data_source_attributes", b"data_source_attributes", "data_source_repository_identifier", b"data_source_repository_identifier", "data_source_repository_name", b"data_source_repository_name", "featureset_repository_identifier", b"featureset_repository_identifier", "featureset_repository_name", b"featureset_repository_name", "source_code_spec", b"source_code_spec", "stream_source", b"stream_source", "type", b"type"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["data_source_repository_identifier", b"data_source_repository_identifier"]) -> typing_extensions.Literal["data_source_repository_name"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["featureset_repository_identifier", b"featureset_repository_identifier"]) -> typing_extensions.Literal["featureset_repository_name"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["type", b"type"]) -> typing_extensions.Literal["batch_source", "stream_source"] | None: ...

global___DataSourceSpec = DataSourceSpec

class FeatureSetBrief(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURE_SET_ID_FIELD_NUMBER: builtins.int
    FEATURE_SET_NAME_FIELD_NUMBER: builtins.int
    FEATURE_SET_TYPE_FIELD_NUMBER: builtins.int
    feature_set_id: builtins.str
    """Feature set id"""
    feature_set_name: builtins.str
    """Feature set name"""
    feature_set_type: builtins.int
    """Feature set type"""
    def __init__(
        self,
        *,
        feature_set_id: builtins.str = ...,
        feature_set_name: builtins.str = ...,
        feature_set_type: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["feature_set_id", b"feature_set_id", "feature_set_name", b"feature_set_name", "feature_set_type", b"feature_set_type"]) -> None: ...

global___FeatureSetBrief = FeatureSetBrief



from .quiet_error import QuietError


class QwakLoginException(QuietError):
    def __init__(
        self, message="Failed to login to Qwak. Please check your credentials"
    ):
        self.message = message



from typing import List, Optional, Union

from _qwak_proto.qwak.model_descriptor.open_ai_descriptor_pb2 import (
    OpenAICapabilities as ProtoOpenAICapabilities,
    OpenAIChatAPI as ProtoOpenAIChatAPI,
    OpenAIChatModelParams as ProtoOpenAIChatModelParams,
    OpenAIModelDescriptor as ProtoOpenAIModelDescriptor,
    ToolChoice as ProtoToolChoice,
    Tools as ProtoTools,
)
from _qwak_proto.qwak.prompt.v1.prompt.prompt_pb2 import (
    PromptModelDescriptor as ProtoPromptModelDescriptor,
    PromptOpenAIProvider as ProtoPromptOpenAIProvider,
)
from google.protobuf import json_format
from google.protobuf.struct_pb2 import ListValue, Struct
from qwak.exceptions import QwakException
from qwak.llmops.generation.chat.openai.types.chat.chat_completion_named_tool_choice_param import (
    ChatCompletionNamedToolChoiceParam,
)
from qwak.llmops.generation.chat.openai.types.chat.chat_completion_tool_param import (
    ChatCompletionToolParam,
)
from qwak.llmops.model.descriptor import ModelDescriptor, OpenAIChat


class ModelDescriptorMapper:
    @staticmethod
    def _from_tool_choice(
        openai_chat_params: ProtoOpenAIChatModelParams,
    ) -> Optional[Union[str, ChatCompletionNamedToolChoiceParam]]:
        _tool_choice: Optional[Union[str, ChatCompletionNamedToolChoiceParam]] = None
        if openai_chat_params.HasField("tool_choice"):
            if openai_chat_params.tool_choice.WhichOneof("value_type") == "json":
                _tool_choice = json_format.MessageToDict(
                    openai_chat_params.tool_choice.json
                )
            elif openai_chat_params.tool_choice.WhichOneof("value_type") == "literal":
                _tool_choice = openai_chat_params.tool_choice.literal
        return _tool_choice

    @staticmethod
    def from_openai_chat_capability(
        model_id: str, openai_chat_params: ProtoOpenAIChatModelParams
    ) -> OpenAIChat:
        p = openai_chat_params
        _tool_choice: Union[str, ChatCompletionNamedToolChoiceParam] = (
            ModelDescriptorMapper._from_tool_choice(
                openai_chat_params=openai_chat_params
            )
        )
        _tools: List[ChatCompletionToolParam] = []

        if p.HasField("tools_spec"):
            for tool in p.tools_spec.tools:
                _tools.append(json_format.MessageToDict(tool))

        return OpenAIChat(
            model_id=model_id,
            frequency_penalty=(
                p.frequency_penalty if p.HasField("frequency_penalty") else None
            ),
            logit_bias=(
                {k: int(v) for k, v in p.logit_bias.items()}
                if p.HasField("logit_bias")
                else None
            ),
            logprobs=p.logprobs if p.HasField("logprobs") else None,
            max_tokens=p.max_tokens if p.HasField("max_tokens") else None,
            n=p.n if p.HasField("n") else None,
            presence_penalty=(
                p.presence_penalty if p.HasField("presence_penalty") else None
            ),
            response_format=(
                p.response_format if p.HasField("response_format") else None
            ),  # noqa
            seed=p.seed if p.HasField("seed") else None,
            stop=[_ for _ in p.stop] if p.HasField("stop") else None,
            temperature=p.temperature if p.HasField("temperature") else None,
            top_p=p.top_p if p.HasField("top_p") else None,
            top_logprobs=p.top_logprobs if p.HasField("top_logprobs") else None,
            user=p.user if p.HasField("user") else None,
            tool_choice=_tool_choice if p.HasField("tool_choice") else None,
            tools=_tools if p.HasField("tools_spec") else None,
        )

    @staticmethod
    def from_prompt_openai_provider(
        open_ai_provider: ProtoPromptOpenAIProvider,
    ) -> ModelDescriptor:
        descriptor: ProtoOpenAIModelDescriptor = (
            open_ai_provider.open_ai_model_descriptor
        )
        model_id: str = descriptor.model_id

        if descriptor.capabilities.WhichOneof("optional_chat"):
            return ModelDescriptorMapper.from_openai_chat_capability(
                model_id=model_id,
                openai_chat_params=descriptor.capabilities.chat_api.chat_params,
            )
        else:
            raise QwakException(
                f"Got unsupported openai capability: {repr(open_ai_provider)}"
            )

    @staticmethod
    def from_prompt_model_descriptor(
        model_descriptor: ProtoPromptModelDescriptor,
    ) -> ModelDescriptor:
        if model_descriptor.WhichOneof("model_provider") == "open_ai_provider":
            return ModelDescriptorMapper.from_prompt_openai_provider(
                model_descriptor.open_ai_provider
            )
        else:
            raise QwakException(
                f"Got unsupported model descriptor: {repr(model_descriptor)}"
            )

    @staticmethod
    def to_openai_chat(model_descriptor: OpenAIChat) -> ProtoOpenAIModelDescriptor:
        d: OpenAIChat = model_descriptor
        logit_bias_struct = Struct()

        logit_bias_struct.update(d.logit_bias) if d.logit_bias else None

        stop_list_value = ListValue()
        stop_list_value.extend(d.stop) if d.stop else None
        tool_choice_proto: ProtoToolChoice

        if isinstance(d.tool_choice, str):
            tool_choice_proto = ProtoToolChoice(literal=d.tool_choice)
        elif d.tool_choice is not None:
            tool_choice_struct = Struct()
            tool_choice_struct.update(d.tool_choice)
            tool_choice_proto = ProtoToolChoice(json=tool_choice_struct)

        tools_structs = []
        if d.tools:
            for tool in d.tools:
                s = Struct()
                s.update(tool)
                tools_structs.append(s)

        tools_proto = ProtoTools(tools=tools_structs)

        model_capabilities = ProtoOpenAICapabilities(
            chat_api=ProtoOpenAIChatAPI(
                chat_params=ProtoOpenAIChatModelParams(
                    frequency_penalty=d.frequency_penalty,
                    logit_bias=logit_bias_struct if d.logit_bias else None,
                    logprobs=d.logprobs,
                    max_tokens=d.max_tokens,
                    n=d.n,
                    presence_penalty=d.presence_penalty,
                    response_format=(
                        d.response_format if d.response_format else None
                    ),  # noqa
                    seed=d.seed,
                    stop=stop_list_value if d.stop else None,
                    temperature=d.temperature,
                    tool_choice=tool_choice_proto if d.tool_choice else None,
                    tools_spec=tools_proto if d.tools else None,
                    top_logprobs=d.top_logprobs,
                    top_p=d.top_p,
                    user=d.user,
                )
            )
        )

        return ProtoOpenAIModelDescriptor(
            model_id=model_descriptor.model_id, capabilities=model_capabilities
        )

    @staticmethod
    def to_model_descriptor(
        model_descriptor: ModelDescriptor,
    ) -> Union[ProtoOpenAIModelDescriptor]:
        if isinstance(model_descriptor, OpenAIChat):
            return ModelDescriptorMapper.to_openai_chat(model_descriptor)

        raise QwakException(
            f"Got unsupported model descriptor: {repr(model_descriptor)}"
        )



from .client import BatchJobManagerClient
from .executions_config import ExecutionConfig
from .results import ExecutionStatusResult

_all_ = ["BatchJobManagerClient", "ExecutionStatusResult", "ExecutionConfig"]



from abc import ABC, abstractmethod
from dataclasses import dataclass
from enum import Enum
from typing import List, Optional

from _qwak_proto.qwak.feature_store.sources.batch_pb2 import (
    DatePartitionColumns as ProtoDatePartitionColumns,
    DayFragmentColumn as ProtoDayFragmentColumn,
    MonthFragmentColumn as ProtoMonthFragmentColumn,
    NumericColumnRepresentation as ProtoNumericColumnRepresentation,
    TextualColumnRepresentation as ProtoTextualColumnRepresentation,
    TimeFragmentedPartitionColumns as ProtoTimeFragmentedPartitionColumns,
    YearFragmentColumn as ProtoYearFragmentColumn,
)


class ColumnRepresentation(Enum):
    """
    Time fragment columns representations
        NumericColumnRepresentation:
            Year:   2020 | '2020'
            Month:  2  | '02' | '2'
            Day:    2  | '02' | '2'
        TextualColumnRepresentation:
            Month: 'Jan' | 'JANUARY' (case-insensitive)
    """

    NumericColumnRepresentation = 1
    TextualColumnRepresentation = 2

    def _to_proto(self):
        if self == ColumnRepresentation.NumericColumnRepresentation:
            res = ProtoNumericColumnRepresentation()
        elif self == ColumnRepresentation.TextualColumnRepresentation:
            res = ProtoTextualColumnRepresentation()
        else:
            raise ValueError(
                f"Unsupported ColumnRepresentation: {self.name}, supported types: {ColumnRepresentation.NumericColumnRepresentation}, {ColumnRepresentation.TextualColumnRepresentation} "
            )
        return res


class FragmentColumn(ABC):
    column_name: str
    representation: ColumnRepresentation

    def __init__(self, column_name: str, representation: ColumnRepresentation):
        if representation not in self._valid_representations:
            raise ValueError(
                f"{self.__class__.__name__} doesn't support representation: {representation}, supported types: {self._valid_representations} "
            )
        self.column_name = column_name
        self.representation = representation

    @property
    @abstractmethod
    def _valid_representations(self) -> List[ColumnRepresentation]:
        pass

    @abstractmethod
    def _to_proto(self):
        pass


class YearFragmentColumn(FragmentColumn):
    _valid_representations: List[ColumnRepresentation] = [
        ColumnRepresentation.NumericColumnRepresentation,
    ]

    def __init__(self, column_name: str, representation: ColumnRepresentation):
        super().__init__(column_name=column_name, representation=representation)

    def _to_proto(self):
        return ProtoYearFragmentColumn(
            column_name=self.column_name,
            numeric_column_representation=self.representation._to_proto(),
        )


class MonthFragmentColumn(FragmentColumn):
    _valid_representations: List[ColumnRepresentation] = [
        ColumnRepresentation.NumericColumnRepresentation,
        ColumnRepresentation.TextualColumnRepresentation,
    ]

    def __init__(self, column_name: str, representation: ColumnRepresentation):
        super().__init__(column_name=column_name, representation=representation)

    def _to_proto(self):
        proto_numeric_column_representation = None
        proto_textual_column_representation = None
        if self.representation == ColumnRepresentation.NumericColumnRepresentation:
            proto_numeric_column_representation = self.representation._to_proto()
        elif self.representation == ColumnRepresentation.TextualColumnRepresentation:
            proto_textual_column_representation = self.representation._to_proto()
        else:
            raise ValueError(
                f"{self.__class__.__name__} partition doesn't support representation: {self.representation}, supported types: {self._valid_representations} "
            )
        return ProtoMonthFragmentColumn(
            column_name=self.column_name,
            numeric_column_representation=proto_numeric_column_representation,
            textual_column_representation=proto_textual_column_representation,
        )


class DayFragmentColumn(FragmentColumn):
    _valid_representations: List[ColumnRepresentation] = [
        ColumnRepresentation.NumericColumnRepresentation
    ]

    def __init__(self, column_name: str, representation: ColumnRepresentation):
        super().__init__(column_name=column_name, representation=representation)

    def _to_proto(self):
        return ProtoDayFragmentColumn(
            column_name=self.column_name,
            numeric_column_representation=self.representation._to_proto(),
        )


@dataclass
class TimePartitionColumns(ABC):
    @abstractmethod
    def _to_proto(self):
        pass


@dataclass
class DatePartitionColumns(TimePartitionColumns):
    date_column_name: str
    date_format: str

    def _to_proto(self):
        return ProtoDatePartitionColumns(
            date_column_name=self.date_column_name,
            date_format=self.date_format,
        )


@dataclass
class TimeFragmentedPartitionColumns(TimePartitionColumns):
    year_partition_column: YearFragmentColumn
    month_partition_column: Optional[MonthFragmentColumn] = None
    day_partition_column: Optional[DayFragmentColumn] = None

    def __post_init__(self):
        if not self.month_partition_column and self.day_partition_column:
            raise ValueError(
                "If day partition column is set then month partition column must be set as well"
            )

    def _to_proto(self):
        return ProtoTimeFragmentedPartitionColumns(
            year_partition_column=self.year_partition_column._to_proto(),
            month_partition_column=(
                self.month_partition_column._to_proto()
                if self.month_partition_column
                else None
            ),
            day_partition_column=(
                self.day_partition_column._to_proto()
                if self.day_partition_column
                else None
            ),
        )



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/feature_store/features/monitoring.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,qwak/feature_store/features/monitoring.proto\x12&qwak.feature.store.features.monitoring\"b\n\x18MonitoringConfigurations\x12\x46\n\nmonitoring\x18\x01 \x03(\x0b\x32\x32.qwak.feature.store.features.monitoring.Monitoring\"c\n\nMonitoring\x12M\n\rfailure_alert\x18\x01 \x01(\x0b\x32\x34.qwak.feature.store.features.monitoring.FailureAlertH\x00\x42\x06\n\x04type\"\x1d\n\x0c\x46\x61ilureAlert\x12\r\n\x05names\x18\x01 \x03(\tB[\n&com.qwak.ai.feature.store.features.apiP\x01Z/qwak/featurestore/features;featurestorefeaturesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.feature_store.features.monitoring_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n&com.qwak.ai.feature.store.features.apiP\001Z/qwak/featurestore/features;featurestorefeatures'
  _globals['_MONITORINGCONFIGURATIONS']._serialized_start=88
  _globals['_MONITORINGCONFIGURATIONS']._serialized_end=186
  _globals['_MONITORING']._serialized_start=188
  _globals['_MONITORING']._serialized_end=287
  _globals['_FAILUREALERT']._serialized_start=289
  _globals['_FAILUREALERT']._serialized_end=318
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from _qwak_proto.qwak.batch_job.v1 import batch_job_service_pb2 as qwak_dot_batch__job_dot_v1_dot_batch__job__service__pb2


class BatchJobManagementServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.StartBatchJob = channel.unary_unary(
                '/qwak.batchjob.BatchJobManagementService/StartBatchJob',
                request_serializer=qwak_dot_batch__job_dot_v1_dot_batch__job__service__pb2.StartBatchJobRequest.SerializeToString,
                response_deserializer=qwak_dot_batch__job_dot_v1_dot_batch__job__service__pb2.StartBatchJobResponse.FromString,
                )
        self.CancelBatchJob = channel.unary_unary(
                '/qwak.batchjob.BatchJobManagementService/CancelBatchJob',
                request_serializer=qwak_dot_batch__job_dot_v1_dot_batch__job__service__pb2.CancelBatchJobRequest.SerializeToString,
                response_deserializer=qwak_dot_batch__job_dot_v1_dot_batch__job__service__pb2.CancelBatchJobResponse.FromString,
                )
        self.StartWarmupJob = channel.unary_unary(
                '/qwak.batchjob.BatchJobManagementService/StartWarmupJob',
                request_serializer=qwak_dot_batch__job_dot_v1_dot_batch__job__service__pb2.StartWarmupJobRequest.SerializeToString,
                response_deserializer=qwak_dot_batch__job_dot_v1_dot_batch__job__service__pb2.StartWarmupJobResponse.FromString,
                )
        self.CancelWarmupJob = channel.unary_unary(
                '/qwak.batchjob.BatchJobManagementService/CancelWarmupJob',
                request_serializer=qwak_dot_batch__job_dot_v1_dot_batch__job__service__pb2.CancelWarmupJobRequest.SerializeToString,
                response_deserializer=qwak_dot_batch__job_dot_v1_dot_batch__job__service__pb2.CancelWarmupJobResponse.FromString,
                )
        self.GetBatchJobStatus = channel.unary_unary(
                '/qwak.batchjob.BatchJobManagementService/GetBatchJobStatus',
                request_serializer=qwak_dot_batch__job_dot_v1_dot_batch__job__service__pb2.GetBatchJobStatusRequest.SerializeToString,
                response_deserializer=qwak_dot_batch__job_dot_v1_dot_batch__job__service__pb2.GetBatchJobStatusResponse.FromString,
                )
        self.GetBatchJobReport = channel.unary_unary(
                '/qwak.batchjob.BatchJobManagementService/GetBatchJobReport',
                request_serializer=qwak_dot_batch__job_dot_v1_dot_batch__job__service__pb2.GetBatchJobReportRequest.SerializeToString,
                response_deserializer=qwak_dot_batch__job_dot_v1_dot_batch__job__service__pb2.GetBatchJobReportResponse.FromString,
                )
        self.UpdateBatchTasksStatus = channel.unary_unary(
                '/qwak.batchjob.BatchJobManagementService/UpdateBatchTasksStatus',
                request_serializer=qwak_dot_batch__job_dot_v1_dot_batch__job__service__pb2.UpdateBatchTasksStatusRequest.SerializeToString,
                response_deserializer=qwak_dot_batch__job_dot_v1_dot_batch__job__service__pb2.UpdateBatchTaskStatusResponse.FromString,
                )
        self.ListBatchJobs = channel.unary_unary(
                '/qwak.batchjob.BatchJobManagementService/ListBatchJobs',
                request_serializer=qwak_dot_batch__job_dot_v1_dot_batch__job__service__pb2.ListBatchJobsRequest.SerializeToString,
                response_deserializer=qwak_dot_batch__job_dot_v1_dot_batch__job__service__pb2.ListBatchJobsResponse.FromString,
                )
        self.GetBatchJobDetails = channel.unary_unary(
                '/qwak.batchjob.BatchJobManagementService/GetBatchJobDetails',
                request_serializer=qwak_dot_batch__job_dot_v1_dot_batch__job__service__pb2.GetBatchJobDetailsRequest.SerializeToString,
                response_deserializer=qwak_dot_batch__job_dot_v1_dot_batch__job__service__pb2.GetBatchJobDetailsResponse.FromString,
                )
        self.GetBatchJobPreSignedUploadUrl = channel.unary_unary(
                '/qwak.batchjob.BatchJobManagementService/GetBatchJobPreSignedUploadUrl',
                request_serializer=qwak_dot_batch__job_dot_v1_dot_batch__job__service__pb2.GetBatchJobPreSignedUploadUrlRequest.SerializeToString,
                response_deserializer=qwak_dot_batch__job_dot_v1_dot_batch__job__service__pb2.GetBatchJobPreSignedUploadUrlResponse.FromString,
                )
        self.GetBatchJobPreSignedDownloadUrl = channel.unary_unary(
                '/qwak.batchjob.BatchJobManagementService/GetBatchJobPreSignedDownloadUrl',
                request_serializer=qwak_dot_batch__job_dot_v1_dot_batch__job__service__pb2.GetBatchJobPreSignedDownloadUrlRequest.SerializeToString,
                response_deserializer=qwak_dot_batch__job_dot_v1_dot_batch__job__service__pb2.GetBatchJobPreSignedDownloadUrlResponse.FromString,
                )
        self.GetBatchJobUploadDetails = channel.unary_unary(
                '/qwak.batchjob.BatchJobManagementService/GetBatchJobUploadDetails',
                request_serializer=qwak_dot_batch__job_dot_v1_dot_batch__job__service__pb2.GetBatchJobUploadDetailsRequest.SerializeToString,
                response_deserializer=qwak_dot_batch__job_dot_v1_dot_batch__job__service__pb2.GetBatchJobUploadDetailsResponse.FromString,
                )
        self.GetBatchJobDownloadDetails = channel.unary_unary(
                '/qwak.batchjob.BatchJobManagementService/GetBatchJobDownloadDetails',
                request_serializer=qwak_dot_batch__job_dot_v1_dot_batch__job__service__pb2.GetBatchJobDownloadDetailsRequest.SerializeToString,
                response_deserializer=qwak_dot_batch__job_dot_v1_dot_batch__job__service__pb2.GetBatchJobDownloadDetailsResponse.FromString,
                )
        self.UpdateDefaultParams = channel.unary_unary(
                '/qwak.batchjob.BatchJobManagementService/UpdateDefaultParams',
                request_serializer=qwak_dot_batch__job_dot_v1_dot_batch__job__service__pb2.UpdateDefaultParamsRequest.SerializeToString,
                response_deserializer=qwak_dot_batch__job_dot_v1_dot_batch__job__service__pb2.UpdateDefaultParamsResponse.FromString,
                )
        self.DeleteDefaultParams = channel.unary_unary(
                '/qwak.batchjob.BatchJobManagementService/DeleteDefaultParams',
                request_serializer=qwak_dot_batch__job_dot_v1_dot_batch__job__service__pb2.DeleteDefaultParamsRequest.SerializeToString,
                response_deserializer=qwak_dot_batch__job_dot_v1_dot_batch__job__service__pb2.DeleteDefaultParamsResponse.FromString,
                )
        self.UpdateTaskIngestedRecordsAmount = channel.unary_unary(
                '/qwak.batchjob.BatchJobManagementService/UpdateTaskIngestedRecordsAmount',
                request_serializer=qwak_dot_batch__job_dot_v1_dot_batch__job__service__pb2.UpdateTaskIngestedRecordsAmountRequest.SerializeToString,
                response_deserializer=qwak_dot_batch__job_dot_v1_dot_batch__job__service__pb2.UpdateTaskIngestedRecordsAmountResponse.FromString,
                )
        self.UpdateTasksDetails = channel.unary_unary(
                '/qwak.batchjob.BatchJobManagementService/UpdateTasksDetails',
                request_serializer=qwak_dot_batch__job_dot_v1_dot_batch__job__service__pb2.UpdateTasksDetailsRequest.SerializeToString,
                response_deserializer=qwak_dot_batch__job_dot_v1_dot_batch__job__service__pb2.UpdateTasksDetailsResponse.FromString,
                )


class BatchJobManagementServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def StartBatchJob(self, request, context):
        """Request from client to create a batch job
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CancelBatchJob(self, request, context):
        """Cancel Job
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StartWarmupJob(self, request, context):
        """Request from client to create a warmup job
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CancelWarmupJob(self, request, context):
        """Cancel warmup
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetBatchJobStatus(self, request, context):
        """Get the status of a batch job
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetBatchJobReport(self, request, context):
        """Get the full batch job report
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateBatchTasksStatus(self, request, context):
        """Update batch task status
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListBatchJobs(self, request, context):
        """Update batch task status
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetBatchJobDetails(self, request, context):
        """Get Batch Job Details
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetBatchJobPreSignedUploadUrl(self, request, context):
        """Get Pre-signed URL for files upload
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetBatchJobPreSignedDownloadUrl(self, request, context):
        """Get Pre-signed URL for files download
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetBatchJobUploadDetails(self, request, context):
        """Get Paths for upload
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetBatchJobDownloadDetails(self, request, context):
        """Get Object keys for download
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateDefaultParams(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteDefaultParams(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateTaskIngestedRecordsAmount(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateTasksDetails(self, request, context):
        """Update the task details for given tasks
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_BatchJobManagementServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'StartBatchJob': grpc.unary_unary_rpc_method_handler(
                    servicer.StartBatchJob,
                    request_deserializer=qwak_dot_batch__job_dot_v1_dot_batch__job__service__pb2.StartBatchJobRequest.FromString,
                    response_serializer=qwak_dot_batch__job_dot_v1_dot_batch__job__service__pb2.StartBatchJobResponse.SerializeToString,
            ),
            'CancelBatchJob': grpc.unary_unary_rpc_method_handler(
                    servicer.CancelBatchJob,
                    request_deserializer=qwak_dot_batch__job_dot_v1_dot_batch__job__service__pb2.CancelBatchJobRequest.FromString,
                    response_serializer=qwak_dot_batch__job_dot_v1_dot_batch__job__service__pb2.CancelBatchJobResponse.SerializeToString,
            ),
            'StartWarmupJob': grpc.unary_unary_rpc_method_handler(
                    servicer.StartWarmupJob,
                    request_deserializer=qwak_dot_batch__job_dot_v1_dot_batch__job__service__pb2.StartWarmupJobRequest.FromString,
                    response_serializer=qwak_dot_batch__job_dot_v1_dot_batch__job__service__pb2.StartWarmupJobResponse.SerializeToString,
            ),
            'CancelWarmupJob': grpc.unary_unary_rpc_method_handler(
                    servicer.CancelWarmupJob,
                    request_deserializer=qwak_dot_batch__job_dot_v1_dot_batch__job__service__pb2.CancelWarmupJobRequest.FromString,
                    response_serializer=qwak_dot_batch__job_dot_v1_dot_batch__job__service__pb2.CancelWarmupJobResponse.SerializeToString,
            ),
            'GetBatchJobStatus': grpc.unary_unary_rpc_method_handler(
                    servicer.GetBatchJobStatus,
                    request_deserializer=qwak_dot_batch__job_dot_v1_dot_batch__job__service__pb2.GetBatchJobStatusRequest.FromString,
                    response_serializer=qwak_dot_batch__job_dot_v1_dot_batch__job__service__pb2.GetBatchJobStatusResponse.SerializeToString,
            ),
            'GetBatchJobReport': grpc.unary_unary_rpc_method_handler(
                    servicer.GetBatchJobReport,
                    request_deserializer=qwak_dot_batch__job_dot_v1_dot_batch__job__service__pb2.GetBatchJobReportRequest.FromString,
                    response_serializer=qwak_dot_batch__job_dot_v1_dot_batch__job__service__pb2.GetBatchJobReportResponse.SerializeToString,
            ),
            'UpdateBatchTasksStatus': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateBatchTasksStatus,
                    request_deserializer=qwak_dot_batch__job_dot_v1_dot_batch__job__service__pb2.UpdateBatchTasksStatusRequest.FromString,
                    response_serializer=qwak_dot_batch__job_dot_v1_dot_batch__job__service__pb2.UpdateBatchTaskStatusResponse.SerializeToString,
            ),
            'ListBatchJobs': grpc.unary_unary_rpc_method_handler(
                    servicer.ListBatchJobs,
                    request_deserializer=qwak_dot_batch__job_dot_v1_dot_batch__job__service__pb2.ListBatchJobsRequest.FromString,
                    response_serializer=qwak_dot_batch__job_dot_v1_dot_batch__job__service__pb2.ListBatchJobsResponse.SerializeToString,
            ),
            'GetBatchJobDetails': grpc.unary_unary_rpc_method_handler(
                    servicer.GetBatchJobDetails,
                    request_deserializer=qwak_dot_batch__job_dot_v1_dot_batch__job__service__pb2.GetBatchJobDetailsRequest.FromString,
                    response_serializer=qwak_dot_batch__job_dot_v1_dot_batch__job__service__pb2.GetBatchJobDetailsResponse.SerializeToString,
            ),
            'GetBatchJobPreSignedUploadUrl': grpc.unary_unary_rpc_method_handler(
                    servicer.GetBatchJobPreSignedUploadUrl,
                    request_deserializer=qwak_dot_batch__job_dot_v1_dot_batch__job__service__pb2.GetBatchJobPreSignedUploadUrlRequest.FromString,
                    response_serializer=qwak_dot_batch__job_dot_v1_dot_batch__job__service__pb2.GetBatchJobPreSignedUploadUrlResponse.SerializeToString,
            ),
            'GetBatchJobPreSignedDownloadUrl': grpc.unary_unary_rpc_method_handler(
                    servicer.GetBatchJobPreSignedDownloadUrl,
                    request_deserializer=qwak_dot_batch__job_dot_v1_dot_batch__job__service__pb2.GetBatchJobPreSignedDownloadUrlRequest.FromString,
                    response_serializer=qwak_dot_batch__job_dot_v1_dot_batch__job__service__pb2.GetBatchJobPreSignedDownloadUrlResponse.SerializeToString,
            ),
            'GetBatchJobUploadDetails': grpc.unary_unary_rpc_method_handler(
                    servicer.GetBatchJobUploadDetails,
                    request_deserializer=qwak_dot_batch__job_dot_v1_dot_batch__job__service__pb2.GetBatchJobUploadDetailsRequest.FromString,
                    response_serializer=qwak_dot_batch__job_dot_v1_dot_batch__job__service__pb2.GetBatchJobUploadDetailsResponse.SerializeToString,
            ),
            'GetBatchJobDownloadDetails': grpc.unary_unary_rpc_method_handler(
                    servicer.GetBatchJobDownloadDetails,
                    request_deserializer=qwak_dot_batch__job_dot_v1_dot_batch__job__service__pb2.GetBatchJobDownloadDetailsRequest.FromString,
                    response_serializer=qwak_dot_batch__job_dot_v1_dot_batch__job__service__pb2.GetBatchJobDownloadDetailsResponse.SerializeToString,
            ),
            'UpdateDefaultParams': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateDefaultParams,
                    request_deserializer=qwak_dot_batch__job_dot_v1_dot_batch__job__service__pb2.UpdateDefaultParamsRequest.FromString,
                    response_serializer=qwak_dot_batch__job_dot_v1_dot_batch__job__service__pb2.UpdateDefaultParamsResponse.SerializeToString,
            ),
            'DeleteDefaultParams': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteDefaultParams,
                    request_deserializer=qwak_dot_batch__job_dot_v1_dot_batch__job__service__pb2.DeleteDefaultParamsRequest.FromString,
                    response_serializer=qwak_dot_batch__job_dot_v1_dot_batch__job__service__pb2.DeleteDefaultParamsResponse.SerializeToString,
            ),
            'UpdateTaskIngestedRecordsAmount': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateTaskIngestedRecordsAmount,
                    request_deserializer=qwak_dot_batch__job_dot_v1_dot_batch__job__service__pb2.UpdateTaskIngestedRecordsAmountRequest.FromString,
                    response_serializer=qwak_dot_batch__job_dot_v1_dot_batch__job__service__pb2.UpdateTaskIngestedRecordsAmountResponse.SerializeToString,
            ),
            'UpdateTasksDetails': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateTasksDetails,
                    request_deserializer=qwak_dot_batch__job_dot_v1_dot_batch__job__service__pb2.UpdateTasksDetailsRequest.FromString,
                    response_serializer=qwak_dot_batch__job_dot_v1_dot_batch__job__service__pb2.UpdateTasksDetailsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'qwak.batchjob.BatchJobManagementService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class BatchJobManagementService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def StartBatchJob(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.batchjob.BatchJobManagementService/StartBatchJob',
            qwak_dot_batch__job_dot_v1_dot_batch__job__service__pb2.StartBatchJobRequest.SerializeToString,
            qwak_dot_batch__job_dot_v1_dot_batch__job__service__pb2.StartBatchJobResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CancelBatchJob(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.batchjob.BatchJobManagementService/CancelBatchJob',
            qwak_dot_batch__job_dot_v1_dot_batch__job__service__pb2.CancelBatchJobRequest.SerializeToString,
            qwak_dot_batch__job_dot_v1_dot_batch__job__service__pb2.CancelBatchJobResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StartWarmupJob(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.batchjob.BatchJobManagementService/StartWarmupJob',
            qwak_dot_batch__job_dot_v1_dot_batch__job__service__pb2.StartWarmupJobRequest.SerializeToString,
            qwak_dot_batch__job_dot_v1_dot_batch__job__service__pb2.StartWarmupJobResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CancelWarmupJob(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.batchjob.BatchJobManagementService/CancelWarmupJob',
            qwak_dot_batch__job_dot_v1_dot_batch__job__service__pb2.CancelWarmupJobRequest.SerializeToString,
            qwak_dot_batch__job_dot_v1_dot_batch__job__service__pb2.CancelWarmupJobResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetBatchJobStatus(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.batchjob.BatchJobManagementService/GetBatchJobStatus',
            qwak_dot_batch__job_dot_v1_dot_batch__job__service__pb2.GetBatchJobStatusRequest.SerializeToString,
            qwak_dot_batch__job_dot_v1_dot_batch__job__service__pb2.GetBatchJobStatusResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetBatchJobReport(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.batchjob.BatchJobManagementService/GetBatchJobReport',
            qwak_dot_batch__job_dot_v1_dot_batch__job__service__pb2.GetBatchJobReportRequest.SerializeToString,
            qwak_dot_batch__job_dot_v1_dot_batch__job__service__pb2.GetBatchJobReportResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateBatchTasksStatus(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.batchjob.BatchJobManagementService/UpdateBatchTasksStatus',
            qwak_dot_batch__job_dot_v1_dot_batch__job__service__pb2.UpdateBatchTasksStatusRequest.SerializeToString,
            qwak_dot_batch__job_dot_v1_dot_batch__job__service__pb2.UpdateBatchTaskStatusResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListBatchJobs(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.batchjob.BatchJobManagementService/ListBatchJobs',
            qwak_dot_batch__job_dot_v1_dot_batch__job__service__pb2.ListBatchJobsRequest.SerializeToString,
            qwak_dot_batch__job_dot_v1_dot_batch__job__service__pb2.ListBatchJobsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetBatchJobDetails(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.batchjob.BatchJobManagementService/GetBatchJobDetails',
            qwak_dot_batch__job_dot_v1_dot_batch__job__service__pb2.GetBatchJobDetailsRequest.SerializeToString,
            qwak_dot_batch__job_dot_v1_dot_batch__job__service__pb2.GetBatchJobDetailsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetBatchJobPreSignedUploadUrl(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.batchjob.BatchJobManagementService/GetBatchJobPreSignedUploadUrl',
            qwak_dot_batch__job_dot_v1_dot_batch__job__service__pb2.GetBatchJobPreSignedUploadUrlRequest.SerializeToString,
            qwak_dot_batch__job_dot_v1_dot_batch__job__service__pb2.GetBatchJobPreSignedUploadUrlResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetBatchJobPreSignedDownloadUrl(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.batchjob.BatchJobManagementService/GetBatchJobPreSignedDownloadUrl',
            qwak_dot_batch__job_dot_v1_dot_batch__job__service__pb2.GetBatchJobPreSignedDownloadUrlRequest.SerializeToString,
            qwak_dot_batch__job_dot_v1_dot_batch__job__service__pb2.GetBatchJobPreSignedDownloadUrlResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetBatchJobUploadDetails(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.batchjob.BatchJobManagementService/GetBatchJobUploadDetails',
            qwak_dot_batch__job_dot_v1_dot_batch__job__service__pb2.GetBatchJobUploadDetailsRequest.SerializeToString,
            qwak_dot_batch__job_dot_v1_dot_batch__job__service__pb2.GetBatchJobUploadDetailsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetBatchJobDownloadDetails(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.batchjob.BatchJobManagementService/GetBatchJobDownloadDetails',
            qwak_dot_batch__job_dot_v1_dot_batch__job__service__pb2.GetBatchJobDownloadDetailsRequest.SerializeToString,
            qwak_dot_batch__job_dot_v1_dot_batch__job__service__pb2.GetBatchJobDownloadDetailsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateDefaultParams(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.batchjob.BatchJobManagementService/UpdateDefaultParams',
            qwak_dot_batch__job_dot_v1_dot_batch__job__service__pb2.UpdateDefaultParamsRequest.SerializeToString,
            qwak_dot_batch__job_dot_v1_dot_batch__job__service__pb2.UpdateDefaultParamsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteDefaultParams(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.batchjob.BatchJobManagementService/DeleteDefaultParams',
            qwak_dot_batch__job_dot_v1_dot_batch__job__service__pb2.DeleteDefaultParamsRequest.SerializeToString,
            qwak_dot_batch__job_dot_v1_dot_batch__job__service__pb2.DeleteDefaultParamsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateTaskIngestedRecordsAmount(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.batchjob.BatchJobManagementService/UpdateTaskIngestedRecordsAmount',
            qwak_dot_batch__job_dot_v1_dot_batch__job__service__pb2.UpdateTaskIngestedRecordsAmountRequest.SerializeToString,
            qwak_dot_batch__job_dot_v1_dot_batch__job__service__pb2.UpdateTaskIngestedRecordsAmountResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateTasksDetails(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.batchjob.BatchJobManagementService/UpdateTasksDetails',
            qwak_dot_batch__job_dot_v1_dot_batch__job__service__pb2.UpdateTasksDetailsRequest.SerializeToString,
            qwak_dot_batch__job_dot_v1_dot_batch__job__service__pb2.UpdateTasksDetailsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/administration/runtime_configuration/v0/external/kafka_config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.administration.runtime_configuration.v0.creds import auth_pb2 as qwak_dot_administration_dot_runtime__configuration_dot_v0_dot_creds_dot_auth__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nHqwak/administration/runtime_configuration/v0/external/kafka_config.proto\x12\x42qwak.administration.runtime_configuration.v0.external.kafka_config\x1a=qwak/administration/runtime_configuration/v0/creds/auth.proto\"\x8f\x02\n\x12KafkaConfiguration\x12\x19\n\x11\x62ootstrap_servers\x18\x01 \x01(\t\x12X\n\nbasic_auth\x18\x02 \x01(\x0b\x32\x42.qwak.administration.runtime_configuration.v0.creds.auth.BasicAuthH\x00\x12|\n\x11security_protocol\x18\x03 \x01(\x0b\x32_.qwak.administration.runtime_configuration.v0.external.kafka_config.KafkaSecurityProtocolConfigH\x00\x42\x06\n\x04\x61uth\"\xa5\x02\n\x1bKafkaSecurityProtocolConfig\x12~\n\nplain_text\x18\x01 \x01(\x0b\x32h.qwak.administration.runtime_configuration.v0.external.kafka_config.KafkaPlainTextSecurityProtocolConfigH\x00\x12q\n\x03ssl\x18\x02 \x01(\x0b\x32\x62.qwak.administration.runtime_configuration.v0.external.kafka_config.KafkaSslSecurityProtocolConfigH\x00\x42\x13\n\x11security_protocol\"&\n$KafkaPlainTextSecurityProtocolConfig\" \n\x1eKafkaSslSecurityProtocolConfigB\xf4\x01\n;com.jfrog.ml.runtime_configuration.v0.external.kafka_configP\x01Z\xb2\x01github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/administration/runtime_configuration/v0/external;runtime_configuration_v0_externalb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.administration.runtime_configuration.v0.external.kafka_config_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n;com.jfrog.ml.runtime_configuration.v0.external.kafka_configP\001Z\262\001github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/administration/runtime_configuration/v0/external;runtime_configuration_v0_external'
  _globals['_KAFKACONFIGURATION']._serialized_start=208
  _globals['_KAFKACONFIGURATION']._serialized_end=479
  _globals['_KAFKASECURITYPROTOCOLCONFIG']._serialized_start=482
  _globals['_KAFKASECURITYPROTOCOLCONFIG']._serialized_end=775
  _globals['_KAFKAPLAINTEXTSECURITYPROTOCOLCONFIG']._serialized_start=777
  _globals['_KAFKAPLAINTEXTSECURITYPROTOCOLCONFIG']._serialized_end=815
  _globals['_KAFKASSLSECURITYPROTOCOLCONFIG']._serialized_start=817
  _globals['_KAFKASSLSECURITYPROTOCOLCONFIG']._serialized_end=849
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from _qwak_proto.qwak.build_settings import build_settings_api_pb2 as qwak_dot_build__settings_dot_build__settings__api__pb2


class BuildSettingsApiStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.SaveBuildSettings = channel.unary_unary(
                '/com.qwak.build_settings.BuildSettingsApi/SaveBuildSettings',
                request_serializer=qwak_dot_build__settings_dot_build__settings__api__pb2.SaveBuildSettingsRequest.SerializeToString,
                response_deserializer=qwak_dot_build__settings_dot_build__settings__api__pb2.SaveBuildSettingsResponse.FromString,
                )
        self.GetBuildSettings = channel.unary_unary(
                '/com.qwak.build_settings.BuildSettingsApi/GetBuildSettings',
                request_serializer=qwak_dot_build__settings_dot_build__settings__api__pb2.GetBuildSettingsRequest.SerializeToString,
                response_deserializer=qwak_dot_build__settings_dot_build__settings__api__pb2.GetBuildSettingsResponse.FromString,
                )
        self.DeleteBuildSettings = channel.unary_unary(
                '/com.qwak.build_settings.BuildSettingsApi/DeleteBuildSettings',
                request_serializer=qwak_dot_build__settings_dot_build__settings__api__pb2.DeleteBuildSettingsRequest.SerializeToString,
                response_deserializer=qwak_dot_build__settings_dot_build__settings__api__pb2.DeleteBuildSettingsResponse.FromString,
                )


class BuildSettingsApiServicer(object):
    """Missing associated documentation comment in .proto file."""

    def SaveBuildSettings(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetBuildSettings(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteBuildSettings(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_BuildSettingsApiServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'SaveBuildSettings': grpc.unary_unary_rpc_method_handler(
                    servicer.SaveBuildSettings,
                    request_deserializer=qwak_dot_build__settings_dot_build__settings__api__pb2.SaveBuildSettingsRequest.FromString,
                    response_serializer=qwak_dot_build__settings_dot_build__settings__api__pb2.SaveBuildSettingsResponse.SerializeToString,
            ),
            'GetBuildSettings': grpc.unary_unary_rpc_method_handler(
                    servicer.GetBuildSettings,
                    request_deserializer=qwak_dot_build__settings_dot_build__settings__api__pb2.GetBuildSettingsRequest.FromString,
                    response_serializer=qwak_dot_build__settings_dot_build__settings__api__pb2.GetBuildSettingsResponse.SerializeToString,
            ),
            'DeleteBuildSettings': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteBuildSettings,
                    request_deserializer=qwak_dot_build__settings_dot_build__settings__api__pb2.DeleteBuildSettingsRequest.FromString,
                    response_serializer=qwak_dot_build__settings_dot_build__settings__api__pb2.DeleteBuildSettingsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'com.qwak.build_settings.BuildSettingsApi', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class BuildSettingsApi(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def SaveBuildSettings(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/com.qwak.build_settings.BuildSettingsApi/SaveBuildSettings',
            qwak_dot_build__settings_dot_build__settings__api__pb2.SaveBuildSettingsRequest.SerializeToString,
            qwak_dot_build__settings_dot_build__settings__api__pb2.SaveBuildSettingsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetBuildSettings(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/com.qwak.build_settings.BuildSettingsApi/GetBuildSettings',
            qwak_dot_build__settings_dot_build__settings__api__pb2.GetBuildSettingsRequest.SerializeToString,
            qwak_dot_build__settings_dot_build__settings__api__pb2.GetBuildSettingsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteBuildSettings(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/com.qwak.build_settings.BuildSettingsApi/DeleteBuildSettings',
            qwak_dot_build__settings_dot_build__settings__api__pb2.DeleteBuildSettingsRequest.SerializeToString,
            qwak_dot_build__settings_dot_build__settings__api__pb2.DeleteBuildSettingsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/analytics/analytics_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.analytics import analytics_pb2 as qwak_dot_analytics_dot_analytics__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&qwak/analytics/analytics_service.proto\x12\x0eqwak.analytics\x1a\x1eqwak/analytics/analytics.proto\"\x1d\n\x0cQueryRequest\x12\r\n\x05query\x18\x01 \x01(\t\"!\n\rQueryResponse\x12\x10\n\x08query_id\x18\x01 \x01(\t\"\'\n\x16\x45xecuteDdlQueryRequest\x12\r\n\x05query\x18\x01 \x01(\t\"+\n\x17\x45xecuteDdlQueryResponse\x12\x10\n\x08query_id\x18\x01 \x01(\t\"T\n\x1aGetQueryResultsPageRequest\x12\x10\n\x08query_id\x18\x01 \x01(\t\x12\x0f\n\x07page_id\x18\x02 \x01(\t\x12\x13\n\x0bmax_results\x18\x03 \x01(\x05\"\xa2\x01\n\x1bGetQueryResultsPageResponse\x12+\n\x06status\x18\x01 \x01(\x0e\x32\x1b.qwak.analytics.QueryStatus\x12\x16\n\x0e\x66\x61ilure_reason\x18\x04 \x01(\t\x12\x14\n\x0cnext_page_id\x18\x02 \x01(\t\x12(\n\x04\x64\x61ta\x18\x03 \x01(\x0b\x32\x1a.qwak.analytics.ResultData\")\n\x15GetQueryStatusRequest\x12\x10\n\x08query_id\x18\x01 \x01(\t\"]\n\x16GetQueryStatusResponse\x12+\n\x06status\x18\x01 \x01(\x0e\x32\x1b.qwak.analytics.QueryStatus\x12\x16\n\x0e\x66\x61ilure_reason\x18\x02 \x01(\t\"A\n\x14\x44\x65scribeTableRequest\x12\x12\n\ntable_name\x18\x01 \x01(\t\x12\x15\n\rdatabase_name\x18\x02 \x01(\t\"Y\n\x15\x44\x65scribeTableResponse\x12\x12\n\ntable_name\x18\x01 \x01(\t\x12,\n\x07\x63olumns\x18\x02 \x03(\x0b\x32\x1b.qwak.analytics.TableColumn\"\x12\n\x10ListTableRequest\"(\n\x11ListTableResponse\x12\x13\n\x0btable_names\x18\x01 \x03(\t\"D\n\x12\x43reateTableRequest\x12.\n\x05table\x18\x01 \x01(\x0b\x32\x1f.qwak.analytics.TableDefinition\"\x15\n\x13\x43reateTableResponse\"`\n GetQueryResultDownloadURLRequest\x12<\n\x06params\x18\x01 \x01(\x0b\x32,.qwak.analytics.QueryResultDownloadURLParams\"9\n!GetQueryResultDownloadURLResponse\x12\x14\n\x0c\x64ownload_url\x18\x01 \x01(\t\"B\n\x14OptimizeTableRequest\x12\x16\n\x0e\x65nvironment_id\x18\x01 \x01(\t\x12\x12\n\ntable_name\x18\x02 \x01(\t\")\n\x15OptimizeTableResponse\x12\x10\n\x08query_id\x18\x01 \x01(\t\".\n\x15\x43reateDatabaseRequest\x12\x15\n\rdatabase_name\x18\x01 \x01(\t\"\x18\n\x16\x43reateDatabaseResponse2\xdd\x07\n\x15\x41nalyticsQueryService\x12\x44\n\x05Query\x12\x1c.qwak.analytics.QueryRequest\x1a\x1d.qwak.analytics.QueryResponse\x12\x62\n\x0f\x45xecuteDdlQuery\x12&.qwak.analytics.ExecuteDdlQueryRequest\x1a\'.qwak.analytics.ExecuteDdlQueryResponse\x12n\n\x13GetQueryResultsPage\x12*.qwak.analytics.GetQueryResultsPageRequest\x1a+.qwak.analytics.GetQueryResultsPageResponse\x12_\n\x0eGetQueryStatus\x12%.qwak.analytics.GetQueryStatusRequest\x1a&.qwak.analytics.GetQueryStatusResponse\x12\\\n\rDescribeTable\x12$.qwak.analytics.DescribeTableRequest\x1a%.qwak.analytics.DescribeTableResponse\x12Q\n\nListTables\x12 .qwak.analytics.ListTableRequest\x1a!.qwak.analytics.ListTableResponse\x12V\n\x0b\x43reateTable\x12\".qwak.analytics.CreateTableRequest\x1a#.qwak.analytics.CreateTableResponse\x12\x80\x01\n\x19GetQueryResultDownloadURL\x12\x30.qwak.analytics.GetQueryResultDownloadURLRequest\x1a\x31.qwak.analytics.GetQueryResultDownloadURLResponse\x12\\\n\rOptimizeTable\x12$.qwak.analytics.OptimizeTableRequest\x1a%.qwak.analytics.OptimizeTableResponse\x12_\n\x0e\x43reateDatabase\x12%.qwak.analytics.CreateDatabaseRequest\x1a&.qwak.analytics.CreateDatabaseResponseB\x86\x01\n\x19\x63om.qwak.ai.analytics.apiP\x01Zggithub.com/qwak-ai/qwak-platform/services/core/java/analytics/analytics-api/pb/qwak/analytics;analyticsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.analytics.analytics_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031com.qwak.ai.analytics.apiP\001Zggithub.com/qwak-ai/qwak-platform/services/core/java/analytics/analytics-api/pb/qwak/analytics;analytics'
  _globals['_QUERYREQUEST']._serialized_start=90
  _globals['_QUERYREQUEST']._serialized_end=119
  _globals['_QUERYRESPONSE']._serialized_start=121
  _globals['_QUERYRESPONSE']._serialized_end=154
  _globals['_EXECUTEDDLQUERYREQUEST']._serialized_start=156
  _globals['_EXECUTEDDLQUERYREQUEST']._serialized_end=195
  _globals['_EXECUTEDDLQUERYRESPONSE']._serialized_start=197
  _globals['_EXECUTEDDLQUERYRESPONSE']._serialized_end=240
  _globals['_GETQUERYRESULTSPAGEREQUEST']._serialized_start=242
  _globals['_GETQUERYRESULTSPAGEREQUEST']._serialized_end=326
  _globals['_GETQUERYRESULTSPAGERESPONSE']._serialized_start=329
  _globals['_GETQUERYRESULTSPAGERESPONSE']._serialized_end=491
  _globals['_GETQUERYSTATUSREQUEST']._serialized_start=493
  _globals['_GETQUERYSTATUSREQUEST']._serialized_end=534
  _globals['_GETQUERYSTATUSRESPONSE']._serialized_start=536
  _globals['_GETQUERYSTATUSRESPONSE']._serialized_end=629
  _globals['_DESCRIBETABLEREQUEST']._serialized_start=631
  _globals['_DESCRIBETABLEREQUEST']._serialized_end=696
  _globals['_DESCRIBETABLERESPONSE']._serialized_start=698
  _globals['_DESCRIBETABLERESPONSE']._serialized_end=787
  _globals['_LISTTABLEREQUEST']._serialized_start=789
  _globals['_LISTTABLEREQUEST']._serialized_end=807
  _globals['_LISTTABLERESPONSE']._serialized_start=809
  _globals['_LISTTABLERESPONSE']._serialized_end=849
  _globals['_CREATETABLEREQUEST']._serialized_start=851
  _globals['_CREATETABLEREQUEST']._serialized_end=919
  _globals['_CREATETABLERESPONSE']._serialized_start=921
  _globals['_CREATETABLERESPONSE']._serialized_end=942
  _globals['_GETQUERYRESULTDOWNLOADURLREQUEST']._serialized_start=944
  _globals['_GETQUERYRESULTDOWNLOADURLREQUEST']._serialized_end=1040
  _globals['_GETQUERYRESULTDOWNLOADURLRESPONSE']._serialized_start=1042
  _globals['_GETQUERYRESULTDOWNLOADURLRESPONSE']._serialized_end=1099
  _globals['_OPTIMIZETABLEREQUEST']._serialized_start=1101
  _globals['_OPTIMIZETABLEREQUEST']._serialized_end=1167
  _globals['_OPTIMIZETABLERESPONSE']._serialized_start=1169
  _globals['_OPTIMIZETABLERESPONSE']._serialized_end=1210
  _globals['_CREATEDATABASEREQUEST']._serialized_start=1212
  _globals['_CREATEDATABASEREQUEST']._serialized_end=1258
  _globals['_CREATEDATABASERESPONSE']._serialized_start=1260
  _globals['_CREATEDATABASERESPONSE']._serialized_end=1284
  _globals['_ANALYTICSQUERYSERVICE']._serialized_start=1287
  _globals['_ANALYTICSQUERYSERVICE']._serialized_end=2276
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.timestamp_pb2
import qwak.administration.v0.environments.environment_pb2
import qwak.user_application.v0.user_application_pb2
import sys
import typing

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class CreateOptions(google.protobuf.message.Message):
    """Options for create user application instance"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IDENTIFIER_FIELD_NUMBER: builtins.int
    KIND_SEM_VERSION_FIELD_NUMBER: builtins.int
    SPEC_FIELD_NUMBER: builtins.int
    RESOURCE_RESERVATION_FIELD_NUMBER: builtins.int
    @property
    def identifier(self) -> global___Identifier:
        """Identifier of user application instance"""
    kind_sem_version: builtins.str
    """Optional: version of the kind, latest if not sent (template version)"""
    @property
    def spec(self) -> qwak.user_application.v0.user_application_pb2.Spec:
        """The specification of the the user application instance"""
    @property
    def resource_reservation(self) -> global___ResourceReservation:
        """Resource reservation for the user application instance"""
    def __init__(
        self,
        *,
        identifier: global___Identifier | None = ...,
        kind_sem_version: builtins.str = ...,
        spec: qwak.user_application.v0.user_application_pb2.Spec | None = ...,
        resource_reservation: global___ResourceReservation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["identifier", b"identifier", "resource_reservation", b"resource_reservation", "spec", b"spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["identifier", b"identifier", "kind_sem_version", b"kind_sem_version", "resource_reservation", b"resource_reservation", "spec", b"spec"]) -> None: ...

global___CreateOptions = CreateOptions

class UpdateSpecOptions(google.protobuf.message.Message):
    """Options for updating user application instance"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IDENTIFIER_FIELD_NUMBER: builtins.int
    SPEC_FIELD_NUMBER: builtins.int
    RESOURCE_RESERVATION_FIELD_NUMBER: builtins.int
    REVISION_RESTRICTION_FIELD_NUMBER: builtins.int
    KIND_VERSION_UPDATE_OPTIONS_FIELD_NUMBER: builtins.int
    STATIC_GLOBAL_CONFIG_UPDATE_OPTIONS_FIELD_NUMBER: builtins.int
    @property
    def identifier(self) -> global___Identifier:
        """Identifier of the user application instance"""
    @property
    def spec(self) -> qwak.user_application.v0.user_application_pb2.Spec:
        """The specification of the the user application instance"""
    @property
    def resource_reservation(self) -> global___ResourceReservation:
        """Resource reservation for the user application instance"""
    @property
    def revision_restriction(self) -> global___RevisionRestriction:
        """Revision restriction"""
    @property
    def kind_version_update_options(self) -> global___KindVersionUpdateOptions: ...
    @property
    def static_global_config_update_options(self) -> global___StaticGlobalConfigurationUpdateOptions: ...
    def __init__(
        self,
        *,
        identifier: global___Identifier | None = ...,
        spec: qwak.user_application.v0.user_application_pb2.Spec | None = ...,
        resource_reservation: global___ResourceReservation | None = ...,
        revision_restriction: global___RevisionRestriction | None = ...,
        kind_version_update_options: global___KindVersionUpdateOptions | None = ...,
        static_global_config_update_options: global___StaticGlobalConfigurationUpdateOptions | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["identifier", b"identifier", "kind_version_update_opt", b"kind_version_update_opt", "kind_version_update_options", b"kind_version_update_options", "resource_reservation", b"resource_reservation", "revision_restriction", b"revision_restriction", "spec", b"spec", "static_global_config_update_options", b"static_global_config_update_options", "static_global_update_opt", b"static_global_update_opt"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["identifier", b"identifier", "kind_version_update_opt", b"kind_version_update_opt", "kind_version_update_options", b"kind_version_update_options", "resource_reservation", b"resource_reservation", "revision_restriction", b"revision_restriction", "spec", b"spec", "static_global_config_update_options", b"static_global_config_update_options", "static_global_update_opt", b"static_global_update_opt"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["kind_version_update_opt", b"kind_version_update_opt"]) -> typing_extensions.Literal["kind_version_update_options"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["static_global_update_opt", b"static_global_update_opt"]) -> typing_extensions.Literal["static_global_config_update_options"] | None: ...

global___UpdateSpecOptions = UpdateSpecOptions

class ResourceReservation(google.protobuf.message.Message):
    """Amount of resources in the reservation"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CPU_CORES_FIELD_NUMBER: builtins.int
    MEMORY_MB_FIELD_NUMBER: builtins.int
    cpu_cores: builtins.float
    """Cpu core"""
    memory_mb: builtins.int
    """Megabyte of RAM"""
    def __init__(
        self,
        *,
        cpu_cores: builtins.float = ...,
        memory_mb: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cpu_cores", b"cpu_cores", "memory_mb", b"memory_mb"]) -> None: ...

global___ResourceReservation = ResourceReservation

class Description(google.protobuf.message.Message):
    """Full description of user application instance"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    METADATA_FIELD_NUMBER: builtins.int
    SPEC_DESCRIPTION_FIELD_NUMBER: builtins.int
    STATUS_DESCRIPTION_FIELD_NUMBER: builtins.int
    @property
    def metadata(self) -> global___Metadata:
        """Metadata of user application instance"""
    @property
    def spec_description(self) -> global___SpecDescription:
        """Spec description"""
    @property
    def status_description(self) -> global___StatusDescription:
        """Status description"""
    def __init__(
        self,
        *,
        metadata: global___Metadata | None = ...,
        spec_description: global___SpecDescription | None = ...,
        status_description: global___StatusDescription | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "spec_description", b"spec_description", "status_description", b"status_description"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "spec_description", b"spec_description", "status_description", b"status_description"]) -> None: ...

global___Description = Description

class SpecDescription(google.protobuf.message.Message):
    """Spec description"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SPEC_FIELD_NUMBER: builtins.int
    STATIC_CONFIGURATION_FIELD_NUMBER: builtins.int
    @property
    def spec(self) -> qwak.user_application.v0.user_application_pb2.Spec:
        """The spec of the user application instance"""
    @property
    def static_configuration(self) -> global___GlobalConfiguration:
        """Configuration on creation / update"""
    def __init__(
        self,
        *,
        spec: qwak.user_application.v0.user_application_pb2.Spec | None = ...,
        static_configuration: global___GlobalConfiguration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["spec", b"spec", "static_configuration", b"static_configuration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["spec", b"spec", "static_configuration", b"static_configuration"]) -> None: ...

global___SpecDescription = SpecDescription

class StatusDescription(google.protobuf.message.Message):
    """Status description"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    @property
    def status(self) -> qwak.user_application.v0.user_application_pb2.Status:
        """Status of the user application instance"""
    def __init__(
        self,
        *,
        status: qwak.user_application.v0.user_application_pb2.Status | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["status", b"status"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["status", b"status"]) -> None: ...

global___StatusDescription = StatusDescription

class Metadata(google.protobuf.message.Message):
    """Metadata of user application instance"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IDENTIFIER_FIELD_NUMBER: builtins.int
    KIND_VERSION_FIELD_NUMBER: builtins.int
    SPEC_LAST_UPDATED_FIELD_NUMBER: builtins.int
    STATUS_LAST_UPDATED_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    CLUSTER_ID_FIELD_NUMBER: builtins.int
    UUID_FIELD_NUMBER: builtins.int
    LAST_DEPLOYED_SPEC_REVISION_FIELD_NUMBER: builtins.int
    SPEC_REVISION_FIELD_NUMBER: builtins.int
    STATUS_REVISION_FIELD_NUMBER: builtins.int
    ENVIRONMENT_SEQUENCER_WHEN_CHANGED_FIELD_NUMBER: builtins.int
    @property
    def identifier(self) -> global___Identifier:
        """Identifier of user application instance"""
    kind_version: builtins.str
    """Kind version (template version) of the user application instance"""
    @property
    def spec_last_updated(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """When the spec has been updated"""
    @property
    def status_last_updated(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """When the status has been updated"""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """When the instance has been created"""
    cluster_id: builtins.str
    """The cluster id which the user applications instance is live in"""
    uuid: builtins.str
    """UUID of user applications instance"""
    last_deployed_spec_revision: builtins.int
    """Last spec revision which has been applied"""
    spec_revision: builtins.int
    """Revision (version) of the user application instance spec"""
    status_revision: builtins.int
    """Revision (version) of the user application instance status"""
    environment_sequencer_when_changed: builtins.int
    """The sequencer value of the environment on the last change"""
    def __init__(
        self,
        *,
        identifier: global___Identifier | None = ...,
        kind_version: builtins.str = ...,
        spec_last_updated: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        status_last_updated: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        cluster_id: builtins.str = ...,
        uuid: builtins.str = ...,
        last_deployed_spec_revision: builtins.int = ...,
        spec_revision: builtins.int = ...,
        status_revision: builtins.int = ...,
        environment_sequencer_when_changed: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["created_at", b"created_at", "identifier", b"identifier", "spec_last_updated", b"spec_last_updated", "status_last_updated", b"status_last_updated"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cluster_id", b"cluster_id", "created_at", b"created_at", "environment_sequencer_when_changed", b"environment_sequencer_when_changed", "identifier", b"identifier", "kind_version", b"kind_version", "last_deployed_spec_revision", b"last_deployed_spec_revision", "spec_last_updated", b"spec_last_updated", "spec_revision", b"spec_revision", "status_last_updated", b"status_last_updated", "status_revision", b"status_revision", "uuid", b"uuid"]) -> None: ...

global___Metadata = Metadata

class Identifier(google.protobuf.message.Message):
    """Identifier of user application instance"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACCOUNT_ID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    ENVIRONMENT_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    account_id: builtins.str
    """Qwak account if of the user applications instance"""
    type: qwak.user_application.v0.user_application_pb2.Type.ValueType
    """User application instance type"""
    environment_id: builtins.str
    """The environment id the user applications instance liviing in"""
    name: builtins.str
    """Name of the user applications instance"""
    def __init__(
        self,
        *,
        account_id: builtins.str = ...,
        type: qwak.user_application.v0.user_application_pb2.Type.ValueType = ...,
        environment_id: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["account_id", b"account_id", "environment_id", b"environment_id", "name", b"name", "type", b"type"]) -> None: ...

global___Identifier = Identifier

class RevisionRestriction(google.protobuf.message.Message):
    """Set a limit on the current revision to eliminate concurrent update"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CURRENT_SPEC_REVISION_FIELD_NUMBER: builtins.int
    current_spec_revision: builtins.int
    """Update only if the current revision is as specified"""
    def __init__(
        self,
        *,
        current_spec_revision: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["current_spec_revision", b"current_spec_revision", "restriction_type", b"restriction_type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["current_spec_revision", b"current_spec_revision", "restriction_type", b"restriction_type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["restriction_type", b"restriction_type"]) -> typing_extensions.Literal["current_spec_revision"] | None: ...

global___RevisionRestriction = RevisionRestriction

class GlobalConfiguration(google.protobuf.message.Message):
    """Global configuration for the application"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENVIRONMENT_FIELD_NUMBER: builtins.int
    @property
    def environment(self) -> qwak.administration.v0.environments.environment_pb2.QwakEnvironment:
        """Environment configuration"""
    def __init__(
        self,
        *,
        environment: qwak.administration.v0.environments.environment_pb2.QwakEnvironment | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["environment", b"environment"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["environment", b"environment"]) -> None: ...

global___GlobalConfiguration = GlobalConfiguration

class KindVersionUpdateOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEEP_EXISTING_VERSION_FIELD_NUMBER: builtins.int
    LATEST_KIND_VERSION_FIELD_NUMBER: builtins.int
    EXPLICIT_KIND_VERSION_FIELD_NUMBER: builtins.int
    @property
    def keep_existing_version(self) -> global___KeepExistingKindVersion:
        """keep the existing kind version (chart version) used by the application"""
    @property
    def latest_kind_version(self) -> global___LatestKindVersion:
        """use the latest kind (chat) version"""
    @property
    def explicit_kind_version(self) -> global___ExplicitKindVersion:
        """use an explicit kind (chart) version"""
    def __init__(
        self,
        *,
        keep_existing_version: global___KeepExistingKindVersion | None = ...,
        latest_kind_version: global___LatestKindVersion | None = ...,
        explicit_kind_version: global___ExplicitKindVersion | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["explicit_kind_version", b"explicit_kind_version", "keep_existing_version", b"keep_existing_version", "latest_kind_version", b"latest_kind_version", "update_type", b"update_type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["explicit_kind_version", b"explicit_kind_version", "keep_existing_version", b"keep_existing_version", "latest_kind_version", b"latest_kind_version", "update_type", b"update_type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["update_type", b"update_type"]) -> typing_extensions.Literal["keep_existing_version", "latest_kind_version", "explicit_kind_version"] | None: ...

global___KindVersionUpdateOptions = KindVersionUpdateOptions

class KeepExistingKindVersion(google.protobuf.message.Message):
    """don't change the kind version"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___KeepExistingKindVersion = KeepExistingKindVersion

class LatestKindVersion(google.protobuf.message.Message):
    """use the latest kind version"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___LatestKindVersion = LatestKindVersion

class ExplicitKindVersion(google.protobuf.message.Message):
    """use an explicit kind version"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KIND_VERSION_FIELD_NUMBER: builtins.int
    kind_version: builtins.str
    def __init__(
        self,
        *,
        kind_version: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["kind_version", b"kind_version"]) -> None: ...

global___ExplicitKindVersion = ExplicitKindVersion

class StaticGlobalConfigurationUpdateOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEEP_EXISTING_STATIC_GLOBAL_CONFIGURATION_FIELD_NUMBER: builtins.int
    REFRESH_STATIC_GLOBAL_CONFIGURATION_FIELD_NUMBER: builtins.int
    @property
    def keep_existing_static_global_configuration(self) -> global___KeepExistingStaticGlobalConfiguration:
        """keep the existing static global configuration"""
    @property
    def refresh_static_global_configuration(self) -> global___RefreshStaticGlobalConfiguration:
        """refresh the static global configuration"""
    def __init__(
        self,
        *,
        keep_existing_static_global_configuration: global___KeepExistingStaticGlobalConfiguration | None = ...,
        refresh_static_global_configuration: global___RefreshStaticGlobalConfiguration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["keep_existing_static_global_configuration", b"keep_existing_static_global_configuration", "refresh_static_global_configuration", b"refresh_static_global_configuration", "update_type", b"update_type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["keep_existing_static_global_configuration", b"keep_existing_static_global_configuration", "refresh_static_global_configuration", b"refresh_static_global_configuration", "update_type", b"update_type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["update_type", b"update_type"]) -> typing_extensions.Literal["keep_existing_static_global_configuration", "refresh_static_global_configuration"] | None: ...

global___StaticGlobalConfigurationUpdateOptions = StaticGlobalConfigurationUpdateOptions

class KeepExistingStaticGlobalConfiguration(google.protobuf.message.Message):
    """keep the existing global configuration, don't refresh it"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___KeepExistingStaticGlobalConfiguration = KeepExistingStaticGlobalConfiguration

class RefreshStaticGlobalConfiguration(google.protobuf.message.Message):
    """refresh the global configuration"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___RefreshStaticGlobalConfiguration = RefreshStaticGlobalConfiguration



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from _qwak_proto.qwak.traffic.v1 import traffic_api_pb2 as qwak_dot_traffic_dot_v1_dot_traffic__api__pb2


class TrafficAPIStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ResetAndSetTrafficState = channel.unary_unary(
                '/qwak.traffic.v1.TrafficAPI/ResetAndSetTrafficState',
                request_serializer=qwak_dot_traffic_dot_v1_dot_traffic__api__pb2.ResetAndSetTrafficStateRequest.SerializeToString,
                response_deserializer=qwak_dot_traffic_dot_v1_dot_traffic__api__pb2.ResetAndSetTrafficStateResponse.FromString,
                )
        self.ApplyGroupedTraffic = channel.unary_unary(
                '/qwak.traffic.v1.TrafficAPI/ApplyGroupedTraffic',
                request_serializer=qwak_dot_traffic_dot_v1_dot_traffic__api__pb2.ApplyGroupedTrafficRequest.SerializeToString,
                response_deserializer=qwak_dot_traffic_dot_v1_dot_traffic__api__pb2.ApplyGroupedTrafficResponse.FromString,
                )
        self.CreateEndpoint = channel.unary_unary(
                '/qwak.traffic.v1.TrafficAPI/CreateEndpoint',
                request_serializer=qwak_dot_traffic_dot_v1_dot_traffic__api__pb2.CreateEndpointRequest.SerializeToString,
                response_deserializer=qwak_dot_traffic_dot_v1_dot_traffic__api__pb2.CreateEndpointResponse.FromString,
                )
        self.DeleteEndpoint = channel.unary_unary(
                '/qwak.traffic.v1.TrafficAPI/DeleteEndpoint',
                request_serializer=qwak_dot_traffic_dot_v1_dot_traffic__api__pb2.DeleteEndpointRequest.SerializeToString,
                response_deserializer=qwak_dot_traffic_dot_v1_dot_traffic__api__pb2.DeleteEndpointResponse.FromString,
                )


class TrafficAPIServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ResetAndSetTrafficState(self, request, context):
        """Reset all the traffic config.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ApplyGroupedTraffic(self, request, context):
        """Update multiple Group traffic configuration (Edit)
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateEndpoint(self, request, context):
        """FirstDeploy
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteEndpoint(self, request, context):
        """LastUndeploy
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_TrafficAPIServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ResetAndSetTrafficState': grpc.unary_unary_rpc_method_handler(
                    servicer.ResetAndSetTrafficState,
                    request_deserializer=qwak_dot_traffic_dot_v1_dot_traffic__api__pb2.ResetAndSetTrafficStateRequest.FromString,
                    response_serializer=qwak_dot_traffic_dot_v1_dot_traffic__api__pb2.ResetAndSetTrafficStateResponse.SerializeToString,
            ),
            'ApplyGroupedTraffic': grpc.unary_unary_rpc_method_handler(
                    servicer.ApplyGroupedTraffic,
                    request_deserializer=qwak_dot_traffic_dot_v1_dot_traffic__api__pb2.ApplyGroupedTrafficRequest.FromString,
                    response_serializer=qwak_dot_traffic_dot_v1_dot_traffic__api__pb2.ApplyGroupedTrafficResponse.SerializeToString,
            ),
            'CreateEndpoint': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateEndpoint,
                    request_deserializer=qwak_dot_traffic_dot_v1_dot_traffic__api__pb2.CreateEndpointRequest.FromString,
                    response_serializer=qwak_dot_traffic_dot_v1_dot_traffic__api__pb2.CreateEndpointResponse.SerializeToString,
            ),
            'DeleteEndpoint': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteEndpoint,
                    request_deserializer=qwak_dot_traffic_dot_v1_dot_traffic__api__pb2.DeleteEndpointRequest.FromString,
                    response_serializer=qwak_dot_traffic_dot_v1_dot_traffic__api__pb2.DeleteEndpointResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'qwak.traffic.v1.TrafficAPI', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class TrafficAPI(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ResetAndSetTrafficState(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.traffic.v1.TrafficAPI/ResetAndSetTrafficState',
            qwak_dot_traffic_dot_v1_dot_traffic__api__pb2.ResetAndSetTrafficStateRequest.SerializeToString,
            qwak_dot_traffic_dot_v1_dot_traffic__api__pb2.ResetAndSetTrafficStateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ApplyGroupedTraffic(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.traffic.v1.TrafficAPI/ApplyGroupedTraffic',
            qwak_dot_traffic_dot_v1_dot_traffic__api__pb2.ApplyGroupedTrafficRequest.SerializeToString,
            qwak_dot_traffic_dot_v1_dot_traffic__api__pb2.ApplyGroupedTrafficResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateEndpoint(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.traffic.v1.TrafficAPI/CreateEndpoint',
            qwak_dot_traffic_dot_v1_dot_traffic__api__pb2.CreateEndpointRequest.SerializeToString,
            qwak_dot_traffic_dot_v1_dot_traffic__api__pb2.CreateEndpointResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteEndpoint(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.traffic.v1.TrafficAPI/DeleteEndpoint',
            qwak_dot_traffic_dot_v1_dot_traffic__api__pb2.DeleteEndpointRequest.SerializeToString,
            qwak_dot_traffic_dot_v1_dot_traffic__api__pb2.DeleteEndpointResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
